@@ -563,16 +563,23 @@ class Project(ProjectPath, HasGroups):
         Iterate over the jobs within the current project and it is sub projects
 
         Args:
-            path (str): HDF5 path inside each job object
-            recursive (bool): search subprojects [True/False] - True by default
-            convert_to_object (bool): load the full GenericJob object (default) or just the HDF5 / JobCore object
-            progress (bool): if True (default), add an interactive progress bar to the iteration
+            path (str): HDF5 path inside each job object. (Default is None, which just uses the top level of the job's
+                HDF5 path.)
+            recursive (bool): search subprojects. (Default is True.)
+            convert_to_object (bool): load the full GenericJob object, else just return the HDF5 / JobCore object.
+                                     (Default is True, convert everything to the full python object.)
+            progress (bool): add an interactive progress bar to the iteration. (Default is True, show the bar.)
             **kwargs (dict): Optional arguments for filtering with keys matching the project database column name
                             (eg. status="finished"). Asterisk can be used to denote a wildcard, for zero or more
                             instances of any character
 
         Returns:
             yield: Yield of GenericJob or JobCore
+
+        Note:
+            The default behavior of converting to object can cause **significant** slowdown in larger projects. In this
+            case, you may seriously wish to consider setting `convert_to_object=False` and access only the HDF5/JobCore
+            representation of the jobs instead.
         """
         job_id_lst = self.job_table(recursive=recursive, **kwargs)["id"]
         if progress:
@@ -648,8 +655,14 @@ class Project(ProjectPath, HasGroups):
         full_table=False,
         element_lst=None,
         job_name_contains="",
+        auto_refresh_job_status=False,
         **kwargs: dict,
     ):
+        """
+        auto_refresh_job_status (bool): will automatically reload job status by calling refresh_job_status() upon calling job_table
+        """
+        if auto_refresh_job_status:
+            self.refresh_job_status()
         return self.db.job_table(
             sql_query=self.sql_query,
             user=self.user,
